@@ -14,7 +14,6 @@ from ..core.types import Point, Schematic, SchematicSymbol, Sheet
 from .symbol_geometry import SymbolGeometry
 
 # Import Rust force-directed placement with defensive fallback
-_RUST_PLACEMENT_AVAILABLE = False
 _rust_placement_module = None
 
 try:
@@ -22,45 +21,23 @@ try:
     import os
     import sys
 
-    # Add rust force-directed placement module to path
-    rust_placement_path = os.path.join(
-        os.path.dirname(__file__),
-        "../../../rust_modules/rust_force_directed_placement/python",
-    )
-    if rust_placement_path not in sys.path:
-        sys.path.insert(0, rust_placement_path)
-
     import_start = time.perf_counter()
-    from rust_force_directed_placement import Component as RustComponent
-    from rust_force_directed_placement import (
-        ForceDirectedPlacer as RustForceDirectedPlacer,
-    )
-    from rust_force_directed_placement import Point as RustPoint
-    from rust_force_directed_placement import (
-        create_component,
-        create_point,
-        validate_placement_inputs,
-    )
-
-    import_time = time.perf_counter() - import_start
-
-    _RUST_PLACEMENT_AVAILABLE = True
-    _rust_placement_module = True
-    logging.getLogger(__name__).info(
-        f"🦀 RUST_PLACEMENT: ✅ RUST FORCE-DIRECTED PLACEMENT MODULE LOADED in {import_time*1000:.2f}ms"
-    )
-    logging.getLogger(__name__).info(
-        f"🚀 RUST_PLACEMENT: Expected 40-60% placement performance improvement"
-    )
-
-except ImportError as e:
-    logging.getLogger(__name__).info(
-        f"🐍 RUST_PLACEMENT: Rust force-directed placement not available ({e}), using Python fallback"
-    )
-except Exception as e:
-    logging.getLogger(__name__).warning(
-        f"⚠️ RUST_PLACEMENT: Unexpected error loading Rust placement module ({e}), using Python fallback"
-    )
+    
+    # Optional Rust placement module
+    try:
+        import rust_force_directed_placement
+        RUST_PLACEMENT_AVAILABLE = True
+        logging.getLogger(__name__).debug("🦀 RUST_PLACEMENT: Rust force-directed placement available")
+    except ImportError as e:
+        RUST_PLACEMENT_AVAILABLE = False
+        logging.getLogger(__name__).info(
+            f"🐍 RUST_PLACEMENT: Rust force-directed placement not available ({e}), using Python fallback"
+        )
+    except Exception as e:
+        RUST_PLACEMENT_AVAILABLE = False
+        logging.getLogger(__name__).warning(
+            f"⚠️ RUST_PLACEMENT: Unexpected error loading Rust placement module ({e}), using Python fallback"
+        )
 
 logger = logging.getLogger(__name__)
 
@@ -1112,4 +1089,4 @@ class PlacementEngine:
             x = center_x + radius * math.cos(angle)
             y = center_y + radius * math.sin(angle)
 
-            comp.position = Point(*self._snap_to_grid((x, y)))
+            comp.position = Point(*self._snap_to_grid((x, y)))
\ No newline at end of file
