@@ -11,6 +11,14 @@ from .cache import (
     cached_jlcpcb_search,
     get_jlcpcb_cache,
 )
+from .fast_search import (
+    FastJLCSearch,
+    FastSearchResult,
+    fast_jlc_search,
+    find_cheapest_jlc,
+    find_most_available_jlc,
+    get_fast_searcher,
+)
 from .jlc_parts_lookup import (
     JlcPartsInterface,
     _calculate_manufacturability_score,
@@ -54,4 +62,11 @@ __all__ = [
     "JLCPCBCache",
     "get_jlcpcb_cache",
     "cached_jlcpcb_search",
+    # Fast search interface
+    "FastJLCSearch",
+    "FastSearchResult",
+    "fast_jlc_search",
+    "find_cheapest_jlc",
+    "find_most_available_jlc",
+    "get_fast_searcher",
 ]
